# Author:: Gerhard Spitzlsperger
# EMAIL and WWW:: ruby@gs68.de, www.gs68.de
# Copyright:: Copyright (c) 2003 Gerhard Spitzlsperger. All rights reserved.
# License:: LGPL see file LICENSE.
# Version 0.1

require 'GS_AreaDialog'
require 'GS_FramePlotCanvas'

require 'fox'
require 'fox/colors'

include Fox


class CanvasWindow < FXMainWindow  

  def initialize(app)
    # Call base class initializer first
    super(app, "Function Plotter", nil, nil, DECOR_ALL,
      0, 0, 800, 600)

    # load some icons  
    killicon = getIcon("kill.gif")
      
    # Make menu bar
    menubar = FXMenubar.new(self, LAYOUT_FILL_X)
    
    # the file menu
    filemenu = FXMenuPane.new(self)  
    FXMenuTitle.new(menubar, "&File", nil, filemenu)
    FXMenuCommand.new(filemenu, "&Quit\tCtl-Q", nil,
      getApp(), FXApp::ID_QUIT)

    # the graphic menu
    graphicmenu = FXMenuPane.new(self)
    FXMenuTitle.new(menubar, "&Graphics", nil, graphicmenu)   
    scaleAxisCmd = FXMenuCommand.new(graphicmenu, "&Scale Axis")
    scaleAxisCmd.connect(SEL_COMMAND, method(:onCmdShowAreaDialog))
     
    # the help menu
    helpmenu = FXMenuPane.new(self)
    FXMenuTitle.new(menubar, "&Help", nil, helpmenu, LAYOUT_RIGHT)
    FXMenuCommand.new(helpmenu, "&About FOX...").connect(SEL_COMMAND) {
      FXMessageBox.information(self, MBOX_OK, "About FOX",
        "FOX is a really, really cool C++ library...\n" +
        "and FXRuby is an even cooler GUI for Ruby!")
    }

    # Place a toolbar above the canvas
    toolbar = FXToolbar.new(self, (LAYOUT_SIDE_TOP|
      PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|FRAME_RAISED|LAYOUT_FILL_X))
 
    FXButton.new(toolbar, "Exit\tExit", killicon, app, FXApp::ID_QUIT,
      ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED)     
 
    # Horizontal divider line
    FXHorizontalSeparator.new(self, SEPARATOR_GROOVE|LAYOUT_FILL_X)

    # initial world coordinates for the drawing canvas
    x_min = 14
    x_max = 19
    y_min = 14.0    
    y_max = 19.0  

    #  splitter takes up the rest of the space
    splitter = FX4Splitter.new(self,
      LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FOURSPLITTER_TRACKING)
       
    # place the four drawing canvases    
    @linlin = GS_FramePlotCanvas.new(splitter, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT), 
      [x_min, y_min, x_max, y_max], "linlin" )
    @linlin.connect(SEL_PAINT) { |sender, sel, event|
      @linlin.draw
    }  
      
    @linlog = GS_FramePlotCanvas.new(splitter, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT), 
      [x_min, y_min, x_max, y_max], "linlog" )
    @linlog.connect(SEL_PAINT) { |sender, sel, event|
      @linlog.draw
    }       
      
    @loglin = GS_FramePlotCanvas.new(splitter, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT), 
      [x_min, y_min, x_max, y_max], "loglin" )
    @loglin.connect(SEL_PAINT) { |sender, sel, event|
      @loglin.draw
    }  
    @loglog = GS_FramePlotCanvas.new(splitter, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT), 
      [x_min, y_min, x_max, y_max], "loglog" )
    @loglog.connect(SEL_PAINT) { |sender, sel, event|
      @loglog.draw
    }      
      
  end

  def onCmdShowAreaDialog(sender, sel, ptr)
    d = GS_AreaDialog.new(self, @linlin.getArea)

    begin  # prepare exception handling
      if d.execute == 1
        area = d.getResults
        @linlin.setArea(area)
	@linlog.setArea(area)
	@loglog.setArea(area)
	@loglin.setArea(area)
      end  
    rescue DrawAreaException
      FXMessageBox.warning(self, MBOX_OK, "Wrong Area Setting", 
        "Please insert a correct area or cancel.")
      retry
    end	# end exception
  end  

  # function to construct a GIF icon
  def getIcon(filename)
    FXGIFIcon.new(getApp(), File.open(filename, "rb").read)
  end
  
  # Create and show the main window
  def create
    super                  # Create the windows
    show(PLACEMENT_SCREEN) # Make the main window appear
  end
end

def run
  # Construct the application object
  application = FXApp.new('Function Plotter', 'Fox Test')
  
  # Initialize it
  application.init(ARGV)
  
  # Construct the main window
  s = CanvasWindow.new(application)
  
  # Create the application
  application.create
  
  # Run the application
  application.run
end



# run the application
run
