# Author:: Gerhard Spitzlsperger
# EMAIL and WWW:: ruby@gs68.de, www.gs68.de
# Copyright:: Copyright (c) 2003 Gerhard Spitzlsperger. All rights reserved.
# License:: LGPL see file LICENSE.
# Version 0.1

require 'GS_AreaDialog'
require 'GS_FramePlotCanvas'

require 'fox'
require 'fox/colors'

include Fox


class CanvasWindow < FXMainWindow  

  def initialize(app)
    # Call base class initializer first
    super(app, "Function Plotter", nil, nil, DECOR_ALL,
      0, 0, 800, 600)

    # load some icons  
    killicon = getIcon("kill.gif")
      
    # Make menu bar
    menubar = FXMenubar.new(self, LAYOUT_FILL_X)
    
    # the file menu
    filemenu = FXMenuPane.new(self)  
    FXMenuTitle.new(menubar, "&File", nil, filemenu)
    FXMenuCommand.new(filemenu, "&Quit\tCtl-Q", nil,
      getApp(), FXApp::ID_QUIT)
     
    # the help menu
    helpmenu = FXMenuPane.new(self)
    FXMenuTitle.new(menubar, "&Help", nil, helpmenu, LAYOUT_RIGHT)
    FXMenuCommand.new(helpmenu, "&About FOX...").connect(SEL_COMMAND) {
      FXMessageBox.information(self, MBOX_OK, "About FOX",
        "FOX is a really, really cool C++ library...\n" +
        "and FXRuby is an even cooler GUI for Ruby!")
    }

    # Place a toolbar above the canvas
    toolbar = FXToolbar.new(self, (LAYOUT_SIDE_TOP|
      PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|FRAME_RAISED|LAYOUT_FILL_X))
 
    FXButton.new(toolbar, "Exit\tExit", killicon, app, FXApp::ID_QUIT,
      ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED)     
 
    # Horizontal divider line
    FXHorizontalSeparator.new(self, SEPARATOR_GROOVE|LAYOUT_FILL_X)

    @canvas = FXCanvas.new(self, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT) )
      
    @canvas.connect(SEL_PAINT) do |canvas, sel, ev|
      dc = FXDCWindow.new(canvas, ev)
      draw(dc)
    end  
  end

  def draw(dc)
    dc = FXDCWindow.new(@canvas)

    dc.foreground = FXColor::White
    
    dc.fillRectangle(0, 0, @canvas.width, @canvas.height)      
    
    dc.foreground = FXColor::Blue
    dc.background = FXColor::White
    dc.drawRectangle(5, 5, 3, 3)
    
    dc.foreground = FXColor::Red
    dc.fillRectangle(5, 5, 3, 3)
    
    dc.foreground = FXColor::Black
    dc.fillRectangle(8, 5, 3, 3)
    
    dc.foreground = FXColor::Red
    dc.drawPoint(13, 13)
    dc.drawPoint(13, 14)
    dc.drawPoint(13, 15)
    dc.drawPoint(13, 16)
    
    #dc.drawLine(10,10, 100,100)
    dc.lineStyle =  LINE_ONOFF_DASH   
    #dc.lineStyle =  LINE_DOUBLE_DASH    
    dc.setDashes(500, [5,10])
    dc.drawLine(10,10, 300,10)
        dc.setDashes(500, [5,15])
    dc.drawLine(10,20, 300,20)
        dc.setDashes(500, [10,15])
    dc.drawLine(10,30, 300,30)
        dc.setDashes(500, [15,15])
    dc.drawLine(10,40, 300,40)
    
    dc.setDashes(500, [5,10])
    w=5
       points = []
    points << FXPoint.new(200, 200)
    points << FXPoint.new(points[0].x+w, 205)
    points << FXPoint.new(points[1].x+w, points[0].y)
    points << FXPoint.new(points[2].x+w, points[1].y)
    points << FXPoint.new(points[3].x+w, points[0].y)
    points << FXPoint.new(points[4].x+w, points[1].y)
       points << FXPoint.new(points[5].x+w, 200)
    points << FXPoint.new(points[6].x+w, points[0].y+w)
    points << FXPoint.new(points[7].x+w, points[1].y)
    points << FXPoint.new(points[8].x+w, points[0].y)
    points << FXPoint.new(points[9].x+w, points[1].y)
    dc.drawLines(points)
  end
  
  # function to construct a GIF icon
  def getIcon(filename)
    FXGIFIcon.new(getApp(), File.open(filename, "rb").read)
  end
  
  # Create and show the main window
  def create
    super                  # Create the windows
    show(PLACEMENT_SCREEN) # Make the main window appear
  end
end

def run
  # Construct the application object
  application = FXApp.new('Function Plotter', 'Fox Test')
  
  # Initialize it
  application.init(ARGV)
  
  # Construct the main window
  s = CanvasWindow.new(application)
  
  # Create the application
  application.create
  
  # Run the application
  application.run
end



# run the application
run
